/*
 * Clock identifiers for clock and power management.
 *
 * Copyright (C) 2021, 2023 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

/* Identifiers for controllable "logical" or "abstract" clocks. Operations
   involving these clocks may operate on multiple "physical" or "specific"
   clocks. */

enum Clock_identifiers
{
  Clock_aic,
  Clock_aic_bitclk,
  Clock_aic_pclk,
  Clock_can0,
  Clock_can1,
  Clock_cdbus,
  Clock_cim,
  Clock_cpu,
  Clock_ddr,
  Clock_dma,
  Clock_emac,
  Clock_external,         /* EXCLK */
  Clock_hclock0,          /* AHB0 */
  Clock_hclock2,          /* AHB2 */
  Clock_hclock2_pclock,   /* AHB2, APB parent clock (JZ4780, X1600) */
  Clock_hdmi,
  Clock_i2c0,
  Clock_i2c1,
  Clock_i2c2,
  Clock_i2c3,
  Clock_i2c4,
  Clock_i2s0,
  Clock_i2s0_rx,
  Clock_i2s0_tx,
  Clock_i2s1,
  Clock_i2s1_rx,
  Clock_i2s1_tx,
  Clock_kbc,
  Clock_lcd,              /* LCD peripheral clock */
  Clock_lcd_pixel0,
  Clock_lcd_pixel1,
  Clock_mac,
  Clock_main,             /* SCLK_A */
  Clock_mipi_csi,
  Clock_msc,              /* MSC parent clock (JZ4780) */
  Clock_msc0,
  Clock_msc1,
  Clock_msc2,
  Clock_none,
  Clock_otg0,
  Clock_otg1,
  Clock_pclock,           /* APB */
  Clock_pcm,
  Clock_pll_A,
  Clock_pll_E,
  Clock_pll_M,
  Clock_pll_V,
  Clock_pwm0,
  Clock_pwm1,
  Clock_rtc,              /* RTCLK */
  Clock_scc,
  Clock_sfc,
  Clock_ssi,              /* SSI parent clock (JZ4780) */
  Clock_ssi0,
  Clock_ssi1,
  Clock_ssi2,
  Clock_timer,
  Clock_uart0,
  Clock_uart1,
  Clock_uart2,
  Clock_uart3,
  Clock_uart4,
  Clock_udc,
  Clock_uhc,
  Clock_uprt,
  Clock_vpu,
  Clock_identifier_count, /* not a clock: limit for array definition */
  Clock_undefined,        /* not a clock: special value */
};

// vim: tabstop=2 expandtab shiftwidth=2
